package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@("`0`````````````#`!8````!````````)>@`````````0```````
M`+(```````!``#@`"0!``!L`&@````8````%`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*A,````````J$P`
M```````0``````$````&````````JW````````"[<````````+MP````````
M!4@````````5>````````!```````@````8```````"KB````````+N(````
M````NX@````````"$`````````(0``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````HA@```````"B&````````*(8`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*MP````````NW``````
M``"[<`````````20````````!)```````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````,````"``````````0````4`````T=.
M50`3]QK.:I;2=@^BY!D7AWG2]+F(10`````````1````2P````0````(A`1`
M!0`0$""``(:````"*`D$(`D``"F""`($ND48H(@`````````2P```$\```!3
M````5````%H```!;````7````%X```!?`````````&$```!B````8P```&0`
M`````````!_?Q6X.[]/J+4?>SGR:?VNVF\4N#N3_(`[QC;A\U&35'%AQV0'&
M1^+`XTNL?)+CNBP_Y<)@;*'Z;XL!L]9#"6MFS*]G[-5%0M-P!XF>XA0-GN/-
MVNW;8C,+ESH-FYRI?PH"I^%)^^"C````````````````````````````````
M```````````#```+````````&Z```````````````J02````````````````
M`````````````R8B`````````````````````````````?82````````````
M`````````````````!$@`````````````````````````````V01````````
M`````````````````````[D2`````````````````````````````O$1````
M`````````````````````````T,2`````````````````````````````242
M`````````````````````````````K\2````````````````````````````
M`,@2`````````````````````````````9<2````````````````````````
M`````JL2`````````````````````````````)@2````````````````````
M`````````2`2`````````````````````````````FD2````````````````
M`````````````O@2`````````````````````````````141````````````
M`````````````````H<2`````````````````````````````7L2````````
M`````````````````````/<1`````````````````````````````4D2````
M`````````````````````````-82`````````````````````````````<42
M`````````````````````````````O\2````````````````````````````
M`C@2`````````````````````````````@P2````````````````````````
M`````;(2`````````````````````````````I82````````````````````
M`````````GH2`````````````````````````````;X2````````````````
M`````````````5<2`````````````````````````````P@2````````````
M`````````````````"T@`````````````````````````````DH2````````
M`````````````````````=`1`````````````````````````````Q42````
M`````````````````````````'@2`````````````````````````````U(2
M`````````````````````````````>\2````````````````````````````
M`*<2`````````````````````````````?L2````````````````````````
M`````S42`````````````````````````````+,2````````````````````
M`````````7`2`````````````````````````````H$2````````````````
M`````````````E<2`````````````````````````````382````````````
M`````````````````H\2`````````````````````````````&H2````````
M`````````````````````2H2`````````````````````````````L82````
M`````````````````````````:<2`````````````````````````````K$2
M`````````````````````````````002````````````````````````````
M`TL2`````````````````````````````IT2````````````````````````
M`````V4A`````````````````````````````8D2````````````````````
M`````````(<2`````````````````````````````#P@````````````````
M`````````````.@2`````````````````````````````6<2````````````
M`````````````````QP2`````````````````````````````D\2````````
M`````````````````````%`@`````````````````````````````V81````
M`````````````````````````N<2`````````````````````````````A02
M`````````````````````````````M02````````````````````````````
M`F`2`````````````````````````````B@2````````````````````````
M`````M\2`````````````````````````````\(2```-````````8"@`````
M````H@```Y`2```.````````86@``````````````^<2```-````````44@`
M```````+!@```U\2```-````````(V`````````"A````Y82```-````````
M26``````````!@``!%42```-````````26@````````"1```!$\2```+````
M````&Z``````````````!((2```-````````7%`````````#U@```W40```8
M````````P+@``````````````\X2```-````````2[``````````-```!`$1
M```/````````89@`````````!````X$0```8````````T.@`````````````
M!$T2```-````````1]``````````/```!&(2```-````````3_@````````!
M3@``!'02```-````````3Q@`````````H````_00```7````````P```````
M`````````]L2```-````````2^@````````!6````VX0```7````````P+@`
M````````````!#81```7````````P+``````````"````X82```-````````
M86```````````@``!"82```-````````8/@`````````:````_H2```-````
M````)>@``````````````_8@```7````````P````````````````Z<2```-
M````````3[@`````````.@``!!`2```-````````2'``````````\```!$`2
M```-````````34`````````!U`!L:6)P97)L+G-O+C4N,C0`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E
M<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T
M97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A
M=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N
M-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M
M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H
M:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X
M<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T
M<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M
M96UM;W9E`&%C8V5S<P!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D
M871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R
M96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A
M=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN
M:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C,N
M-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````````"``(``P````(``@`"``(`
M`@`"```````"```````$``(````"```````````````"``4``P````(``@`"
M````!@````(````"`````@`#`````P`$```````"``(````"```````&````
M!`````(``@`"```````````````"``(````"``(``P`"``(``P`"``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0````$``0```=\````0````(`UI:1(````#```$F````````0`$```"+@``
M`!``````"6D9=`````8```2B````$`EI&7(````%```$K@```!`-:6D4````
M!```!+H````0#6EI$@````(```28`````````````+MP``````````P`````
M```F^````````+MX``````````P````````FJ````````+_```````````P`
M``````#`"````````+_8``````````P````````C8````````,`(````````
M``P```````#`"````````,`0``````````P```````!C6@```````,`8````
M``````P```````!C0@```````,`@``````````P```````!C2@```````,`H
M``````````P```````!C<````````,`P``````````P```````!C6```````
M`,`X``````````P```````!C:@```````,!(``````````P```````!D8```
M`````,!0``````````P```````!B4````````,!@``````````P```````!C
M!@```````,!H``````````P```````!C"@```````,!P``````````P`````
M``!D9@```````,!X``````````P```````!B5@```````,"```````````P`
M``````!D;@```````,"0``````````P```````!D<@```````,"8````````
M``P```````!D>````````,"P``````````P```````!E&@```````+^(````
M`P````H``````````````````+^0````!0````H``````````````````+^8
M````"`````H``````````````````+^@````#0````H`````````````````
M`+^H````$P````H``````````````````+^P````%@````H`````````````
M`````+^X````(P````H``````````````````+_(````)0````H`````````
M`````````+_0````,0````H``````````````````+_@````/0````H`````
M`````````````+_H````/@````H``````````````````+_P````0P````H`
M`````````````````+_X````1`````H``````````````````+VP`````@``
M``L``````````````````+VX`````P````L``````````````````+W`````
M!`````L``````````````````+W(````!P````L``````````````````+W0
M````"0````L``````````````````+W8````"@````L`````````````````
M`+W@````"P````L``````````````````+WH````#`````L`````````````
M`````+WP````#@````L``````````````````+WX````#P````L`````````
M`````````+X`````$`````L``````````````````+X(````$0````L`````
M`````````````+X0````$@````L``````````````````+X8````%`````L`
M`````````````````+X@````%0````L``````````````````+XH````%P``
M``L``````````````````+XP````&`````L``````````````````+XX````
M&0````L``````````````````+Y`````&@````L``````````````````+Y(
M````&P````L``````````````````+Y0````'`````L`````````````````
M`+Y8````'0````L``````````````````+Y@````'@````L`````````````
M`````+YH````'P````L``````````````````+YP````(`````L`````````
M`````````+YX````(0````L``````````````````+Z`````(@````L`````
M`````````````+Z(````)`````L``````````````````+Z0````)@````L`
M`````````````````+Z8````)P````L``````````````````+Z@````*```
M``L``````````````````+ZH````*0````L``````````````````+ZP````
M*@````L``````````````````+ZX````*P````L``````````````````+[`
M````+`````L``````````````````+[(````+0````L`````````````````
M`+[0````+@````L``````````````````+[8````+P````L`````````````
M`````+[@````,`````L``````````````````+[H````,@````L`````````
M`````````+[P````,P````L``````````````````+[X````-`````L`````
M`````````````+\`````-0````L``````````````````+\(````-@````L`
M`````````````````+\0````-P````L``````````````````+\8````.```
M``L``````````````````+\@````.0````L``````````````````+\H````
M.@````L``````````````````+\P````/`````L``````````````````+\X
M````/P````L``````````````````+]`````0`````L`````````````````
M`+](````00````L``````````````````+]0````0@````L`````````````
M`````+]8````10````L``````````````````+]@````1@````L`````````
M`````````+]H````1P````L``````````````````+]P````2`````L`````
M`````````````+]X````20````L``````````````````+^`````2@````L`
M`````````.MO\#``)+D$`!^G^_]@XQ#P```DP,```%#RP!```%'_XQ`0```$
MN0(`$:>$``,-X>-`\1``!.MO\-``!`?T!P?C$/`X`"3`$```4-G2!_`P$`CC
M$!`0``0'\0<`!P`'`,`0``!0V.,0$```!`?Q#1#C$!`,`!3`]/___^4`````
MP!```%#,XQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```4,#C$!````0'
M\0T0XQ`0#``4P/3____%````,,`0``!0M.,0$```!`?Q#1#C$!`,`!3`]/__
M_[4```!(P!```%"HXQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```4)SC
M$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!0D.,0$```!`?Q#1#C$!`,
M`!3`]/___X4```"0P!```%"$XQ`0```$!_$-$.,0$`P`%,#T____=0```*C`
M$```4'CC$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!0;.,0$```!`?Q
M#1#C$!`,`!3`]/___U4```#8P!```%!@XQ`0```$!_$-$.,0$`P`%,#T____
M10```/#`$```4%3C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!02.,0
M$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```%`\XQ`0```$!_$-$.,0$`P`
M%,#T____%0```3C`$```4##C$!````0'\0T0XQ`0#``4P/3___\%```!4,`0
M``!0).,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```%`8XQ`0```$!_$-
M$.,0$`P`%,#T___^Y0```8#`$```4`SC$!````0'\0T0XQ`0#``4P/3___[5
M```!F,`0``!0`.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```$_TXQ`0
M```$!_$-$.,0$`P`%,#T___^M0```<C`$```3^CC$!````0'\0T0XQ`0#``4
MP/3___ZE```!X,`0``!/W.,0$```!`?Q#1#C$!`,`!3`]/___I4```'XP!``
M`$_0XQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```3\3C$!````0'\0T0
MXQ`0#``4P/3___YU```"*,`0``!/N.,0$```!`?Q#1#C$!`,`!3`]/___F4`
M``)`P!```$^LXQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```3Z#C$!``
M``0'\0T0XQ`0#``4P/3___Y%```"<,`0``!/E.,0$```!`?Q#1#C$!`,`!3`
M]/___C4```*(P!```$^(XQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`$```
M3WSC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!/<.,0$```!`?Q#1#C
M$!`,`!3`]/___@4```+0P!```$]DXQ`0```$!_$-$.,0$`P`%,#T___]]0``
M`NC`$```3UCC$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!/3.,0$```
M!`?Q#1#C$!`,`!3`]/___=4```,8P!```$]`XQ`0```$!_$-$.,0$`P`%,#T
M___]Q0```S#`$```3S3C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0``!/
M*.,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$\<XQ`0```$!_$-$.,0
M$`P`%,#T___]E0```WC`$```3Q#C$!````0'\0T0XQ`0#``4P/3___V%```#
MD,`0``!/!.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$[XXQ`0```$
M!_$-$.,0$`P`%,#T___]90```\#`$```3NSC$!````0'\0T0XQ`0#``4P/3_
M__U5```#V,`0``!.X.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!```$[4
MXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```3LCC$!````0'\0T0XQ`0
M#``4P/3___TE```$(,`0``!.O.,0$```!`?Q#1#C$!`,`!3`]/___14```0X
MP!```$ZPXQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```3J3C$!````0'
M\0T0XQ`0#``4P/3___SU```$:,`0``!.F.,0$```!`?Q#1#C$!`,`!3`]/__
M_.4```2`P!```$Z,XQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```3H#C
M$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!.=.,0$```!`?Q#1#C$!`,
M`!3`]/___+4```3(P!```$YHXQ`0```$!_$-$.,0$`P`%,#T___\I0``!.#`
M$```3ESC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!.4.,0$```!`?Q
M#1#C$!`,`!3`]/___(4```40P!```$Y$XQ`0```$!_$-$.,0$`P`%,#T___\
M=0``!2C`$```3CCC$!````0'\0T0XQ`0#``4P/3___QE```%0,`0``!.+.,0
M$```!`?Q#1#C$!`,`!3`]/___%4```58P!```$X@XQ`0```$!_$-$.,0$`P`
M%,#T___\10``!7#K;_`P`"3`T```'SWC\/\X_W'C,/"H`"3C0/"@`"10(/"T
MLD\`$.L1`"``#;)/`!%!0/"@03#PJ-('\,`0*$$@\+3`Y?___?_$2```3A3$
M*```3AFY!``TP.4``!Z,Q!@``$WYE0`0`*>$`+[$N```3>[C(+```!;`Y?__
M_W26`B3RXR"P```6P.7___]L6!#PM)8!)/+L(0`%`-CC$-````2Y%``B["$`
MSB!EZR(``P`-P.7___U'P!```%9<Y4P0```$P!```"!WXS#PJ``$XT`P```$
MXQ`@"``DXT`@```DQ!@``$XWXQ`@$``DQ"L``%8]P!```"!AXQ`@&``D6`#P
MM.P,`!L!?D$P,`BG6``%[$#__P#8N10`%>.P,```!.L1``,`#>.Q+_C_)*=:
M``&G.P`(IT;_\>P0``0`V+D4`!'K$0`#``WC$2_X_W&Y!`!2[$```P#8IVD`
M`+D4`$3E2!````#`,```$:3$*```5@G`Y?___D88LNPH`$T`?L0H``!5_T&@
M\+S`Y?___&JY!``ZP"```![6P.4```UJ["@`0P!\Q"@``%7LP.7___P9P.7_
M__WVLD\`$.L1`"``#;)/`!&Y%``KU0?PP!`HIW0`4>-`\3@`!.MO\/@`!`?T
MP.7___QNQ"L``%7+["@`10!\P.7___OEQ+@``$TFXR"P```6P.7___ZLD@`H
M]:?T_S#$*```5;7`Y?___F(8LJ?T_Z_`$```5:CC(!````*GA``0P.4``!U(
MI_3_M<0X``!-$\`@```?(,#E___]6;D$`#K`(```'DW`Y0``#0G$*P``58KL
M*/^?`'RG]/_DP.7___O&IRD``<#E___\P0<'!P=!0/`(XS#P```$IPG_\+F`
M`/"G^_]0UP?P`/``Z^_PH``D07#PH,!@```=J<!0```=<L`@``!,W^,@(```
M!,#E___\S0``!P?`$```343`(```34%!$!`'N0D`$NP<``H.?<08``!,H^P8
M``0`?`?Q!_X'!P<'!P?`$```32S`,```32FY"0`QZS,``P`*ZQ,`/P`,N0@`
M,>LS``$`"NPX``T`?,08``!,LNP8``<`?,`@``!-$`?Q!_X'!P<'!P?KO_!8
M`"3`L```307C\/]@_W&5`+``IW0`%<`0``!,8^,0$````J>$``C$*```3)O`
MY?__^J3`Y?___ZF2`;``XT#Q$``$Z[_P^``$!_0'!\`@``!*1.,0(````J=T
M``7`]/___ZS$&```3&WL&/_Z`'SK[_!P`"3C\/]@_W$-X>OO\1``!,#T____
MF0<'!P>R3P`0ZQ$`(``-LD\`$>MO\#``)*=9``CC\/S0_W'2!_,H$"A!L"`X
M01#PJ+D$`$'C,+````3K`P`@``SC`$```"3`.@````#C,$`(`"1!L+`(ITL`
M$*=7_^U!4/*HXS`0:``$XS`00`""XS`0$`""XS`0``""[$,@OV%9[$,@/@%6
MXT`0@``DIQL`".Q1_^E@9.-`(```!..@(!``!.,`(`@`!.PT(+]E6>R0(+]^
M6>PT(#H%5NR0("$>5N.`\*@`!+GGD!K"BEJ">9FY@``4XX`@(``(N>>@<;D(
M`(/C4"`8``2GN?__N>=0.KF``#"Y@@`UN0@`...`\+``!.QC(+\`5<**6H)Y
MF;GH4!BY"``7N>>P=KF``'GKU@`;``SLA""_?EGLUB`Z!5;LA"`A'E:Y@``X
MN8$`-^-P\+@`!,)Z6H)YF;D(`'JY"``=N0@`-^S1(+\`5>N]`!L`#.R](#H%
M5K/!``NSS0!PX[#PP``$PKI:@GF9N0@`-[D(`+FG>?__ZY8``@`,N>=P?>R6
M("$>5KF``'BY@``9N8$`<;D(`'OL8R"_`%7CL/#(``3K%@`;``S"NEJ">9GL
M%B`Z!5:Y"`"XN0@`%^N-``(`#*=Y___LC2`A'E:YYW!VN8``.+F``'FY@0!S
MN0@`>^S1(+\`5>.P\-``!.L]`!L`#,*Z6H)YF>P](#H%5KD(`+FY"``WZY8`
M`@`,IWG__^R6("$>5KGG<'VY@``9N8``>+F!`'&Y"`![[&,@OP!5X[#PV``$
MZQ8`&P`,PKI:@GF9[!8@.@56N0@`N+D(`!?KC0`"``RG>?__[(T@(1Y6N>=P
M=KF``#BY@`!YN8$`<[D(`'OLT2"_`%7CL/#@``3K/0`;``S"NEJ">9GL/2`Z
M!5:Y"`"YN0@`-^N6``(`#*=Y___LEB`A'E:YYW!]N8``&;F``'BY@0!QN0@`
M>^QC(+\`5>.P\.@`!.L6`!L`#,*Z6H)YF>P6(#H%5KD(`+BY"``7ZXT``@`,
MIWG__^R-("$>5KGG<':Y@``XN8``>;F!`'.Y"`![[-$@OP!5X[#P\``$ZST`
M&P`,PKI:@GF9[#T@.@56N0@`N;D(`#?KE@`"``RG>?__[)8@(1Y6N>=P?;F`
M`!FY@`!XN8$`<;D(`'OL8R"_`%7CL/#X``3K%@`;``S"NEJ">9GL%B`Z!5:Y
M"`"XN0@`%^N-``(`#*=Y___LC2`A'E:YYW!VN8``.+F``'FY@0!SN0@`>^S1
M(+\`5>.P\0``!.L]`!L`#,*Z6H)YF>P](#H%5KD(`+FY"``WZY8``@`,IWG_
M_^R6("$>5KGG<'VY@``9N8``>+F!`'&Y"`![[&,@OP!5X[#Q"``$ZQ8`&P`,
MPKI:@GF9[!8@.@56N0@`N+D(`!?KC0`"``RG>?__[(T@(1Y6N>=P=KF``#BY
M@`!YN8$`<[D(`'OLT2"_`%7CL/$0``3K/0`;``S"NEJ">9GL/2`Z!5:Y"`"Y
MN0@`-^N6``(`#*=Y___LEB`A'E:YYW!]N8``&;F``'BY@0!QN0@`>^QC(+\`
M5>.P\1@`!.L6`!L`#,*Z6H)YF>P6(#H%5KD(`+BY"``7ZXT``@`,IWG__^R-
M("$>5KGG<':Y@``XN8``>;F!`'.Y"`![[-$@OP!5X[#Q(``$ZST`&P`,PKI:
M@GF9[#T@.@56N0@`N;D(`#?KE@`"``RG>?__[)8@(1Y6N>=P?;F``!FY@`!X
MN8$`<;D(`'OL8R"_`%7CL/$H``3K%@`;``S"NEJ">9GL%B`Z!5:Y"`"XN0@`
M%^N-``(`#*=Y___LC2`A'E:YYW!VN8``.+F``'FY@0!SN0@`>^S1(+\`5>.P
M\3``!.L]`!L`#,*Z6H)YF>P](#H%5KD(`+FY"``WZY8``@`,IWG__^R6("$>
M5KGG<'VY@``9N8``>+F!`'&Y"`![[&,@OP!5X[#Q.``$ZQ8`&P`,PKI:@GF9
M[!8@.@56N0@`N+D(`!>GB?__ZWT``@`,N>>`ANQ]("$>5KGDD-BY@``WN8$`
MT[D(`-OL@2"_`%7CL/%```3K.``;``S"NEJ">9GL."`Z!5:Y"`"YN0@`/>N6
M`!X`#:?9___K9@`"``RYY]#8N8``U[F!`);L:2"_`%6Y@``6N8$`'>S3(+\`
M5;D(`!OKO0`;``SLO2`Z!5:Y"``;Z[@`'@`-ZX@``@`,N8$`B^.P\4@`!+F"
M`)C"NF[9ZZ&Y@@"3N0@`>^N]`!X`#;D:`'FY!`"7[#$@OP!5Z]T``@`,ZW,`
M&P`,N8$`V^QS(#H%5KGGT+BY"`!YXY#Q4``$PIINV>NAN0@`:;GG$)OKLP`>
M``VY&@!I[!<@OP!5ZS,``@`,ZY$`&P`,[)$@.@56N0@`EKGF,&NYYV"]N8(`
M>^,P\5@`!.NQ`!X`#<(Z;MGKH>L1``(`#+D:`#BY&@`WN00`<^R)(+\`5>LX
M`!L`#.PX(#H%5KD(`#>YYA![XQ#Q8``$N>=PML(:;MGKH;D:`!VYYY#;N1H`
M';D$`-'LDR"_`%7KN``>``WK&0`;``SKB``"``SL&2`Z!5:Y@0"+N0@`'>S1
M(+\`5>.P\6@`!,*Z;MGKH;D:`+:Y!`!KN>>`M[F"`#OKN0`>``VY&@!CZYD`
M`@`,L\$`)KGFD&NYYV"8N8(`D;/-`!+C,/%P``3".F[9ZZ&Y&@`WZWT`&P`,
MN1H`.>Q](#H%5NN=``(`#+D(`!>Y!`"SZWT`'@`-[#$@OP!5N8$`>;GG<):Y
MYQ`9XQ#PH``DZ],`&P`,XQ#Q>``$[-,@.@56PAINV>NAN0@`V[D:`!CLG2"_
M`%7C$/"D`!KKN0`;``RY!`"!N00`&^NS`!X`#>P9(#H%5KD(`!CK@P`"``RY
M@0"+N>>`M^,P\8``!+F"`-O".F[9ZZ&Y&@`V[&$@OP!5N1H`/>NV`!L`#+D$
M`-.Y!``[Z[D`'@`-ZYD``@`,N8$`F[GGD+CL-B`Z!5:Y@@`;N0@`/>/0\8@`
M!,+:;MGKH;D:`-?L<R"_`%6Y&@#1Z[<`&P`,[+<@.@56N00`';D$`-OKM@`>
M``WK9@`"``RY@0!KN>=@N;D(`-&Y@@`[XQ#QD``$PAINV>NAN1H`&.R-(+\`
M5;D:`!/KN``;``RY!``QN00`&^NW`!X`#>MW``(`#+F!`'NYYW"VN8(`O>P8
M(#H%5KD(`!/C,/&8``3".F[9ZZ&Y&@`YN1H`.^NX`!X`#>N(``(`#+F!`(NY
MYX"W[)$@OP!5N8(`&^O9`!L`#.S9(#H%5KD(`-/C,/&@``3".F[9ZZ&Y&@`V
M[&T@OP!5N1H`,>NV`!L`#+D$`!.Y!``[Z[D`'@`-ZYD``@`,N8$`F[GGD+BY
M@@"][#8@.@56N0@`,>,0\:@`!,(:;MGKH;D:`!>Y&@`;Z[8`'@`-ZV8``@`,
MN8$`:[GG8+GL<R"_`%6Y@@`[Z]<`&P`,[-<@.@56N0@`T>,0\;``!,(:;MGK
MH;D:`!CLC2"_`%6Y&@`3Z[@`&P`,N00`,;D$`!OKMP`>``WK=P`"``RY@0![
MN>=PMKF"`+WL&"`Z!5:Y"``3XS#QN``$PCINV>NAN1H`.;D:`#OKN``>``WK
MB``"``RY@0"+N>>`M^R1(+\`5;F"`!OKV0`;``SLV2`Z!5:Y"`#3XS#QP``$
MPCINV>NAN1H`-NQM(+\`5;D:`#'KM@`;``RY!``3N00`.^NY`!X`#>N9``(`
M#+F!`)NYYY"XN8(`O>PV(#H%5KD(`#'C$/'(``3"&F[9ZZ&Y&@`7N1H`&^NV
M`!X`#>MF``(`#+F!`&NYYV"Y[',@OP!5N8(`.^O7`!L`#.S7(#H%5KD(`-'C
M$/'0``3"&F[9ZZ&Y&@`8[(T@OP!5N1H`$^NX`!L`#+D$`#&Y!``;Z[<`'@`-
MZW<``@`,N8$`>[GG<+:Y@@"][!@@.@56N0@`$^,P\=@`!,(Z;MGKH;D:`#FY
M&@`[Z[@`'@`-ZX@``@`,N8$`B[GG@+?LD2"_`%6Y@@`;Z]D`&P`,[-D@.@56
MN0@`T^,P\>``!,(Z;MGKH;D:`#;L;2"_`%6Y&@`QZ[8`&P`,N00`$[D$`#OK
MN0`>``WKF0`"``RY@0";N>20N.PV(#H%5KD(`#'C$/'H``3"&H\;O-RY&@`7
MN>:0>+F``'WLTR"_`%6Y@0![Z[T`&P`,[+T@.@56N1H`%[D$`'OKM@`>``WK
M9@`"``RY@0!KN>1@N;D(`''C$/'P``3"&H\;O-RY&@`8N>9@B;F``(/L-R"_
M`%6Y@0"+Z[,`&P`,N1H`&+/!``NY!`"QL\T`$.N-`!X`#>O=``(`#.P3(#H%
M5KD(`!OCL/'X``3"NH\;O-RY&@"YN8$`C;D$`)NYY("VN>:`UKF``-?L<2"_
M`%6Y@0#;Z[<`&P`,N1H`G>RW(#H%5KD$`-FY!`";Z[,`'@`-N0@`G>O3``(`
M#+F!`-NYY-"XXS#R```$PCJ/&[S<N1H`-KGFT&BY@`!A[!D@OP!5N8$`:^NQ
M`!L`#+D:`#:Y!`!CN00`.^NW`!X`#>PQ(#H%5NMW``(`#+D(`#:Y@0![XV#R
M"``$N>1PO<)JCQN\W+D:`&BYYG"-N8``F.R#(+\`5;F!`)OKN``;``SLN"`Z
M!5:Y&@!IN00`F^NQ`!X`#;D(`);K80`"``RY@0!KN>1@M^,0\A``!,(:CQN\
MW+D:`!VYYF#7N8``T^PY(+\`5;F!`-OKLP`;``RY&@`=N00`T;D$`!OKN``>
M``WL$R`Z!5;KB``"``RY"``=N8$`B^/0\A@`!+GD@+;"VH\;O-RY&@#7N>:`
M=KF``)?L<2"_`%6Y@0";Z[<`&P`,[+<@.@56N1H`V;D$`)OKLP`>``VY"`"=
MZ],``@`,N8$`V[GDT+CC,/(@``3".H\;O-RY&@`VN>;0:+F``&'L&2"_`%6Y
M@0!KZ[$`&P`,N1H`-KD$`&.Y!``[Z[<`'@`-[#$@.@56ZW<``@`,N0@`-KF!
M`'OC8/(H``2YY'"]PFJ/&[S<N1H`:+GF<(VY@`"8[(,@OP!5N8$`F^NX`!L`
M#.RX(#H%5KD:`&FY!`";Z[$`'@`-N0@`ENMA``(`#.,0\C``!+F!`&O"&H\;
MO-RYY&"WN1H`';GF8->Y@``][-D@OP!5N8$`.^N]`!L`#+D:`!.Y!``QN00`
M&^NX`!X`#>P=(#H%5KD(`!/K.``"``RY@0`[N>8PMNR!(+\`5;F``)NYY#"V
MN8$`F^N]`!X`#>O=``(`#+F!`-NYYM"SN8``&[GDT+.Y@0`;X[#R0``$PKJ/
M&[S<N1H`MKD$`&OCL/(X``3"NH\;O-RY&@"WN1H`8;D$`'OK&``;``RY&@!Y
M[!@@.@56Z[@`'@`-N>@0E^L8``(`#.R)(+\`5;F!`!OKN``;``RYYA!][+@@
M.@56N8``E[GHL':YY!"]N8$`F^NX`!X`#>-@\D@`!.N(``(`#,)JCQN\W+F!
M`(NY&@!CN>:`L;D:`&FY!`"6[#<@OP!5ZV,`&P`,[&,@.@56N0@`:>.0\E``
M!,*:CQN\W+D:`)VYY'#;N>2`L>QV(+\`5;F!`-OKMP`;``RY&@"=[+<@.@56
MN00`V;D$`)OKLP`>``VY"`"=Z],``@`,XS#R6``$N8$`V\(ZCQN\W+GDT+BY
M&@`QN00`$[GFT#BY@``V[&D@OP!5N8$`.^NV`!L`#+D:`!.Y!``[Z[<`'@`-
M[#8@.@56ZW<``@`,N0@`,;F!`'OC$/)@``2YY'"]PAJ/&[S<N1H`&+GF<(VY
M@`"8[(,@OP!5N8$`F^NX`!L`#+D:`!FY!`"1N00`&^NV`!X`#>P8(#H%5NMF
M``(`#+D(`!FY@0!KXY#R:``$N>1@M\*:CQN\W+D:`)VYYF#7N8``/>S1(+\`
M5;F!`#OKO0`;``RY&@"3[+T@.@56N00`.;D$`)OKN``>``VY"`"3ZX@``@`,
MXS#R<``$N8$`B\(ZCQN\W+GD@+:Y&@`WN>:`=KF``!?L>2"_`%6Y@0`;Z[<`
M&P`,N1H`,;D$`!.Y!``[Z[T`'@`-[#<@.@56Z]T``@`,N0@`,;F!`-OC$/)X
M``2YY-"XPAJ/&[S<N1H`%KGFT&BY@`"6[&,@OP!5N8$`F^NV`!L`#+D:`!FY
M!`"1N00`&^NW`!X`#>P6(#H%5NMW``(`#+D(`!FY@0![XY#R@``$N>1PO<*:
MCQN\W+D:`)BYYG"-N8``..R!(+\`5;F!`#OKN``;``RY&@"3[+@@.@56N00`
M.;D$`)OKM@`>``WK9@`"``RY@0!KN>=@M[D(`).Y@@`;XS#RB``$PCK*8L'6
MN1H`/>S9(+\`5;D:`#'KO0`;``RY!``3N00`.^NX`!X`#>N(``(`#+F!`(NY
MYX"V[#T@.@56N8(`F[D(`#'C$/*0``3"&LIBP=:Y&@`7[',@OP!5N1H`&>NW
M`!L`#+D$`)&Y!``;Z[T`'@`-Z]T``@`,N8$`V[GGT+CL%R`Z!5:Y@@`[N0@`
M&>.0\I@`!,*:RF+!UKD:`);L82"_`%6Y&@"3Z[8`&P`,[+8@.@56N00`.;D$
M`)OKMP`>``WK=P`"``RY@0![N>=PO;D(`).Y@@`;XS#RH``$PCK*8L'6N1H`
M..R)(+\`5;D:`#'KN``;``RY!``3N00`.^NV`!X`#>MF``(`#+F!`&NYYV"W
M[#@@.@56N8(`F[D(`#'C$/*H``3"&LIBP=:Y&@`=[-,@OP!5N1H`&>N]`!L`
M#+D$`)&Y!``;Z[@`'@`-ZX@``@`,N8$`B[GG@+;L'2`Z!5:Y@@`[N0@`&>.0
M\K``!,*:RF+!UKD:`)?L<2"_`%6Y&@"3Z[<`&P`,[+<@.@56N00`.;D$`)OK
MO0`>``WKW0`"``RY@0#;N>?0N+D(`).Y@@`;XS#RN``$PCK*8L'6N1H`-NQI
M(+\`5;D:`#'KM@`;``RY!``3N00`.^NW`!X`#>MW``(`#+F!`'NYYW"][#8@
M.@56N8(`F[D(`#'C$/+```3"&LIBP=:Y&@`8[(,@OP!5N1H`&>NX`!L`#+D$
M`)&Y!``;Z[8`'@`-ZV8``@`,N8$`:[GG8+?L&"`Z!5:Y@@`[N0@`&>.0\L@`
M!,*:RF+!UKD:`)WLT2"_`%6Y&@"3Z[T`&P`,[+T@.@56N00`.;D$`)OKN``>
M``WKB``"``RY@0"+N>>`MKD(`).Y@@`;XS#RT``$PCK*8L'6N1H`-^QY(+\`
M5;D:`#'KMP`;``RY!``3N00`.^N]`!X`#>O=``(`#+F!`-NYY]"X[#<@.@56
MN8(`F[D(`#'C$/+8``3"&LIBP=:Y&@`6[&,@OP!5N1H`&>NV`!L`#+D$`)&Y
M!``;Z[<`'@`-ZW<``@`,N8$`>[GG<+WL%B`Z!5:Y@@`[N0@`&>.0\N``!,*:
MRF+!UKD:`)CL@2"_`%6Y&@"3Z[@`&P`,[+@@.@56N00`.;D$`)OKM@`>``WK
M9@`"``RY@0!KN>=@M[D(`).Y@@`;XS#RZ``$PCK*8L'6N1H`/>S9(+\`5;D:
M`#'KO0`;``RY!``3N00`.^NX`!X`#>N(``(`#+F!`(NYYX"V[#T@.@56N8(`
MF[D(`#'C$/+P``3"&LIBP=:Y&@`7[',@OP!5N1H`&>NW`!L`#+D$`)&Y!``;
MZ[T`'@`-Z]T``@`,N8$`V[GGT+CL%R`Z!5:Y@@`[N0@`&>.0\O@`!,*:RF+!
MUKD:`);L82"_`%6Y&@"3Z[8`&P`,[+8@.@56N00`.;D$`)OKMP`>``WK=P`"
M``RY@0![N>=PO;F"`!NY"`"3XS#S```$PCK*8L'6N1H`..R)(+\`5;D:`#'K
MN``;``RY!``3N00`.^NV`!X`#>PX(#H%5NMF``(`#+D(`#&Y@0!KXQ#S"``$
MPAK*8L'6N1H`';GG8->Y@@"=N1H`&>S3(+\`5;D$`)'KN``>``WK'0`;``SL
M'2`Z!5:Y"``9ZY@``@`,N8$`F[GGD+:Y@@`[XX#S$``$PHK*8L'6N1H`A^QQ
M(+\`5;D:`(/KMP`;``RY!``X[+<@.@56N00`B^N]`!X`#;D(`(/K/0`"``SC
MT/,8``3"VLIBP=:Y&@#6N8$`.[D$`&WCL"`@``2YYS#9N1H`L[F"`!W`N@``
M``#CL"`@`"2Y&@!A[+@@OP!5Z]<`'@`-ZQL`&P`,ZW<``@`,[!L@.@56N8$`
M?;D(`!:YYW!CP!H`````N>@0,.,`\R``!,`Z`````.,P(`@`),(*RF+!UKF"
M`(:Y&@!7N00`,,!:`````.-0(!@`)+D:`#GK`0`;``RY&@`X[`$@.@56ZQL`
M`@`,N0@`,.P;("$>5KD:`$.Y"`"AP$H`````XT`@```DP*H`````XZ`@$``D
MLD\`$.L1`"``#;)/`!'5!_,H$"BG=``)XT#SH``$ZV_S8``$!_3`Y?__[LP'
M!^MO\#``)./P_V#_<>PH`&<`?,08``!`"^-P$````J>$`%[C$"```)3L&`!5
M`'[L&`!2/7ZY!`"209"0`>,0D```E.P8``8`?NP6__@]?AN2XZ!P```"IX0`
M([D$`(*Y!`!CN10`F;D$`+>Y!`!)N00`.+D$`"K`Y?__\1WL)@`)`'Y!&:``
ME3T0`*>$`!)!L+`(XZ"P```"IW3_Z;D$`"KC0/$0``3K;_#0``0']$&IH`&Y
MZ7`;N00`*NL1``,`"E`08`#C0/$0``3K;_#0``0']*>8``"G]/^]IZD``*?T
M_]\'!P<'!P?KK_!0`"2R3P`0X_#_4/]QZQ$`(``-LD\`$;D$`*+2!_"H$"A!
ML/"DN00`.[D$`"K`Y?___W3L*``M`'S$*```/X+C$/"D`!3K$0`#``WC$"``
M``CC(!`(``3C(!```"3L*/_D`'Q!$!`(XR`0"``$XR`0```D[";_^`!\N00`
M.[D$`"K`Y?___TKL)O_9`'RR3P`0ZQ$`(``-LD\`$=4'\*@0**=T``GC0/$@
M``3KK_$```0'],#E___M^0<'!P?K;_`P`"3`T```$!'C\/]`_W&R3P`0ZQ$`
M(``-LD\`$;D$`+.G.```T@?PN!`HXQ"P``"4P!<````]N?L0$Z<(``#CL-``
M`(BGF0``N00`HKD$`!M!,/"TLEX`D:<4__ZY"0";P.7___[Z["@`LP!\IP@`
M`*<9``"Y!``RLEX`$Z<4__ZY"0`2[)$`B,!EXV#PM``4Q(@``#[VZV8``P`-
MXQ"@``"4[!@!$@!^[!@!#SU^N00`&J?T``7L*``+/7Y!$!`!XR`0``"4[";_
M^`!^N0D`&KD4`!&Y!`!V02D0`N-P@```",#E___N4>,@<```).PH`/8`?.,0
MH```D.,P@```!.,@\+0`%.LB``,`#>,B,```!$(0(`!!H*`!N90`$>P6`!,`
M?J?T`!/C$*```)!"$"`!0:"@`4$@(`&YE``1[!@`!@!^[!;_\CU^DCT@`*<9
M``#C,;```)!",2`!IQL``>PV__D`?*<H``"R3P`0ZQ$`(``-LD\`$=4'\+@0
M*+D4`"*G=`"PXU#Q,``$ZV_P\``$!_5!L+`!02`@`>,0O___D.,0+___<NP8
M_]\`?$&PL`%!("`!XQ"___^0XQ`O__]R[!;_Z0!\I_3_S\2(```^6.-@@```
M!.,08````J>$`'BY!``6IR@``*?T``,8)^QR``$`V$$0$`CC,!````*G=/_W
MIRH``[D4`"+K(@`#``W`$```1IGC$!```!*GA``NN00`,KD$`";`Y?__[/WC
M((```"3L*`!2`'RY%``7XR#PH``DXQ#PJ``DZV$``P`-XQ#PJ``$XR#PH``$
MIQL``>L1``,`#4$1(`#E2!````!0</"TI_3_$\`0``!&9>5,$````<#E___M
M?^,@\*``).PH`"0`?+D4`$?C0/"H`"2Y!``VZV0``P`-N00`1L#E___L*N,0
M\*``!.,0@```)*?T_\BG&0``I_3_!:<I`!"G>```I_3_GJ<H__^G]/]&P.7_
M_^R!!P<'!^MO\#``)+D$`._C\/ZX_W&GZ__X8(#@`+)/`!#K$0`@``VR3P`1
MT@?Q.!`H["@`"0!\N00`@I4`(`"G=``7LD\`$.L1`"``#;)/`!'5!_$X$"BG
M=`"E:(#Q0.-`\;@`!.MO\7@`!`?TP.7__^\XN00`DNPH_^8`?*>H`"Y!</"H
MN00`*<#E___NNNPH`'$`?.,0(!,`E+G[$!JG5``-XQ`@%`"4[!C_[@!^N?L0
M&J>D`&L3$>P8_^8`?J<(``!!L"`3N00`&*<I``"R7@`AIQ3__KD$`#NG&0``
MLEX`$Z<4__ZY"0`;N0D`*!HAIRH``KD4`"*Y!`!HP.7__^S0X[#PH``DL\$`
M@J=)__^G.0`!P%````Y`P.7__^UAL\T`.+D$`$>G*0`!P.7__^Z(["@`#?]^
M6!#PP*<H0`#`&P``\`#L$@`F@':SS0`HP.7__^R6L\T`*,#E___K<;D$`"G`
MY?__[DSL)O^5`'RY!``IP.7__^Z4N00`*,#E___KCZ?T_U_C$"`5`)2G]/^5
ML\T`*,#E____-Z?T_]W`Y?__ZZX'!P<'!P?KK_!0`"3C\/]@_W&Y!`"BQ+@`
M`#S$XR"P```6P.7__^Y*N00`.NQ"`?@`V:<I``'`Y?__[E#L*``.`'ZG*```
MXT#Q$``$N10`(NNO\/``!`?TXR"P```6P.7__^XL6!`B$*<H0`#`&P``\`#L
M$@`3@';C(+```!;`Y?__[AQ8$"(0I2^@`,`;``#P`.P2_]A@=KD$`"JG.0`"
MP.7__^V+$"+C0/$0``2G*O__ZZ_P\``$B"``'[D4`"(']`<'!P?KC_!``"2R
M3P`0X_#_6/YQZQ$`(``-XU#PH`%QLD\`$=('4``0*+D$`(-!L/"@N00`DKD$
M`#NG20__P"````UZP.7__^N8["P`2`!^[!+__P#8N10`H>,Z\*``D*<Q`/^G
MA``XN10`HKD$`$JY!``KISD`+\#E___LSNPH`"X`?,08```\+.,@$```%L#E
M___MLKD$`%JY!`!+N00`.<#E___M6;)/`!#C(/"@`7'K$0`@``VR3P`1U0<@
M`!`HIW0`'N-`\1@!!.N/\.@!!`?T[!;_S`!^Q!@``#P!XR`0```6P.7__^V'
MN00`2+D$`#G`Y?__ZQ"G]/_7P.7__^K+Z^_P<``DQ!@``#OIX_#_8/]QXR`0
M```6P.7__^ULP%````S]Q$@``#O6P#````T*Z^_Q$``$P/3__^P]!P<'!^MO
M\#``)./P_UC_<<2X```[QN,@L```%L!@```.=,#E___M2<#E____SN,@L```
M%L#E___M0+D$`%;E2/"@``#`0```"@#`,```#.K`Y?__[*+C0/$8``3K;_#8
M``0'].MO\#``)+)/`!#C\/](_7'K$0`@``WC(/"P`G&R3P`1T@<@`!`HP.7_
M_^L5P!````S80;#PKKD$`&+`4```#,NY!``KXQ#PH``DITD0`:<Y``'`Y?__
MZ[_L)`!%`'ZY!``KXY#PKP%QITD0`+D$`#G`Y?__ZK"Y!`"R["0`-`!^IRH`
M`;D4`"+`Y?__ZP2Y!`"B["@`$`!\N10`N[D$`#FY!`!+P.7__^G601N@`)(`
M$`"R3P`0XS#PL`)QZQ$`(``-LD\`$;D$`"K5!S``$"BG=``-XT#Q*`($ZV_P
MZ`($!_2GJ0``I_3_YL#E___J`\#T____B`<'ZV_P,``DLD\`$./P_T#^<>L1
M`"``#>-`\+@!<;)/`!'2!T``$"BY!`"RN00`D\`@```,7D$P\+3`Y?__^QBG
M.0`ON00`HKD$`"O`Y?__ZN?L*``C`'RY!``[P"````Q-P.7___O8N00`*[)/
M`!#C,/"X`7'K$0`@``VR3P`1U0<P`!`HIW0`W>-`\3`!!.MO\/`!!`?TIP@`
M`+D$`!NY!``IP#````PPIYD``+)>`)&G%/_^&YO`Y?__Z^'L*/_-`'RGF@`!
M07#PN,"````,'94`(`"GA`"%[*@`#P!\IP@``+D$`!*Y!``ZLET`$Z<4__ZG
MA`!GN00`$J<(``"G.0``LEX`,:<4__ZY"0`R&!.Y%``SXS,O__]QE2\P`*=T
M`!&G&O__N10`,4%#(`"2`$``XS,O__]QE2\P`*>$__,:&:<X#__L$_^((';C
ML/"H`"3C@/"@`"2Y!`!BITD0`*<Y``'`4```#%VY!``GP.7__^JUQ&@``#IF
MXR!@```6P.7__^OLN00`-^Q"`?@`V:<I``'`Y?__Z]+L)@`3`'[C(&```!;`
MY?__Z]E8$"(0I2^``,`;``#P`.P2`"F`=L`P```+H:<I``#`Y?__ZU?L*/]#
M`'R5`"``IW3_?^RH`!``?,`0```+@J<(``"Y!``JLET`$J<4__ZGA/_CP"``
M``MUIQ@``:?T_YRY!``GISD``<#E___K(NPF_],`?KD$`#?`(```"VC`Y?__
M^O.Y!``GP.7__^J2I_3_&,#E___HW0<'!P?`4```"OSC$"```)#L&``3`'P8
M04$0(`&]05``XS`0``"0N>*`(1A#IQL``>PV__8`?`?^!P<'!^OO\'``)./P
M_V#_<>PH`#``?.,P(```E.PX`"H`?J<(``"G&0``N00`0K)>`!2G%/_^XQ`?
M__]Q["$`0*!EE2\0`*=T`"NYZ2!!XQ`?__]QIT<`(.PX``PO?L`@```+%>OO
M\1``!,#T___J.:<I``+`Y?__Z53L*`!@`'SE1"``+@#C0/$0``3K[_$0``0'
M])4O$`"GA/_;N>D@0>-0'___<>PE`%,@9>PH`%#_?.,0'___<:='`#7L(?_.
M@&2YZ2!!XS`?__]Q[",`1"!E["@`0?]\XQ`?__]QIT<`*+D)`!*G21``[#$`
M`@#9[#0`)2!EN00`,D%`$`&G61``P"```#GMP.7__^HJP"```#GGXT#Q$``$
MZ^_Q$``$!_25+Q``IW3_QJ?T_\R5+Q``IX3_TZ?T_]:G*0``XT#Q$``$Z^_Q
M$``$!_2G20`!I_3_L:=)``&G]/_`Z[_P6``DLD\`$.L1`"``#;)/`!'C\/\P
M_W'`(```"HK2!_#($"C`$```"B+2(?"F$`#`Y?__^:/`(```"H!!L/"@P.7_
M__F;P"````I\P.7___F5P"````I[P.7___F/P"````IYP.7___F)P"````I[
MP.7___F#P"````I-P.7___E]P"````IUP.7___EWP"````ITP.7___EQP"``
M``ISP.7___EKP"````HZP.7___EEP"````ILP.7___E?P"````IKP.7___E9
MN00`.\`@```*:<#E___XW>PH``L`?+D$`#+`(```"DG`Y?__^::Y!``[P"``
M``I?P.7___C*["@`"P!\N00`,L`@```*7<#E___YD[D$`#O`(```"EO`Y?__
M^+?L*``G`'RY!``RP"````GPP.7___F`P#````IAP"````H'P.7___EWLD\`
M$.L1`"``#;)/`!'5!_#($"BG=``UXT#Q0``$Z[_Q*``$!_2Y!``[P"````HT
MP.7___B(["@`#0!\N00`,L`@```)[\#E___Y4:?T_]&G20`*P#````HH02#P
MM\#E___IR>PF_\4`?D$P\,'`(```"=C`Y?__^3JG]/^ZP.7__^<I!P<'!^OO
M\'``)+)/`!#C\/]0_W'K$0`@``VR3P`1Q"T``#B[T@?PJ!`H["@`&/]^LD\`
M$.L1`"``#;)/`!'5!_"H$"BY%``BIW0`*^-`\2``!.OO\2``!`?T03#PI,`@
M```)GL#E___X+.PH`!8`?.,0(```D.P8`!``?,`7````,+D#`"'K(@`_``S$
M+P``.(2G]/_/IR@``*?T__G`Y?__YM?K[_!P`"3C\/]@_W'`Y?__YM[`Y?__
MYDOL*``-`'SC("````3C0/$0``3K[_$0``0']*<I``"G]/_W!P<'!P<'ZV_P
M,``DN00`[^/P_P#_<:?K__A@@.``LD\`$.L1`"``#;)/`!'2!_#P$"C`$```
M-_;2-_"X$`#CH/"X``*GA``ZN00`@D&P\,!!</"TP-````D2I_0`$;D$`#C`
MY?__Y=;L*``]`'RGNP`(XZ"_^/\"IX0`(+D$`#>Y!``JP.7___>MN00`DNPH
M``<`?)4`(`"G=/_CN00`*KD$`#BGNP`(P.7___AOXZ"_^/\"IW3_Y+)/`!#K
M$0`@``VR3P`1U0?P\!`HIW0`06B`\/CC0/%P``3K;_$P``0']*<(``"Y!``8
MLEX`(:<4__ZY!``YIQD``+)>`!.G%/_^N0D`&;D)`"A!(A`"N00`:,#E___F
M_N.0\*@`)./0\*``)+/!`(+`4```"3:G2?__ISD``<#E___GC+/-`#BY!``J
MP.7___@AI_3_DL#E___F$`<'ZV_P,``DP-````A!N00`[^/P_>CW<:?K_^!@
M@.``8,#@"&#@X!!@D.`8LD\`$.L1`"``#;)/`!'C,/'P"''2!S``$"C`$```
M-U[2%_#0$`#`$```-V32+_$`$`#`$```-W;2%_#H$`!!</#,N00`DKD$`#?`
M(```"$O`Y?__]P?L*``)`'RY!`"RE0`@`*=T`F3`Y?___N^Y!`"R["@":0!\
MN00`&Z<(``"G*0``LEX`(:<4__ZY"0`KZR(``0`-IRL``<#E___F>N,0L```
MD+D$`*(88>P8`!X`?+D$`(JY!``HN80`9L!0```(IZ=)__^G.0`!0;"P`4&`
M@`+`Y?__YOWC$+```)`88>P6_^H`?.,@\0```J>$`"M!L/$(I_0`":>[``CC
M(+_X_P*GA``@N00`-\#E___VJ;D$`(+L*/_R`'R5`"``IX3_[<#E___YO>PH
M_^@`?KD$`"C`Y?__YPVY!`!B["8`*0!\IX@``+D4`!CK$0`#``WCL?#0``*G
MA``:E0"P`*>$`!:Y!``KP.7___F;["8`JP!^IXH``;D4`!CK$0`#``WCL?#0
M``*G=/_JIVD``*<(``"Y!``FIQD``+)>`!*G%/_^N00`.KD$`"&G&0``N0D`
M)K)>`!.G%/_^N0D`&AH2IQH$!,"P```'FN.P\,``)+D4`(&Y!``HP.7__^7:
MXZ#PL``DX[#PH``DP!````@8XQ#PJ``DL\$`@J<Y``'`4```"`FG2?__P.7_
M_^9BL\T`**<Y`<#`Y?__YHOL*`!A_W[$J```-@GC(*```!;`Y?__YX^SS0`X
M[$(!^`#9IRD``<#E___GE1BR["@`;@!^L\T`:,08```UZ.-0D```!,!````(
M'.,@$```!*<Y``&GB0``P.7__^;,LD\`$.,P\?`(<>L1`"``#;)/`!&Y!``H
MU0<P`!`HIW0$&.V`\?@(9>W`\@`(9>W@\@@(9>V0\A`(9>-`\H@(!.MO\D@(
M!`?TN00`*Z>*``'`Y?__YD'L*/\[`'RY!`!BI_3_6L#E___EYU@0(`#L&/^=
M$7ZSS0!HN10`$>-0D```!.,0\*``),08```UD<!````'C.,@$```!*<Y``&G
MB0``P.7__^9XI_3_K.,@H```%L#E___G$%@0(A"G*$``P!L``/``[!+_B&!V
MXR"@```6P.7__^<`6&`B%,#E___D6^QB_WI@=N,@H```%L#E___F\E@0(A"G
M*`'`P!L```'_[!+_:F!VN00`*,#E___E`[D$`#>Y!`""P"````<TP.7___5A
M["@!`P!\XZ"0```$P.7__^70N00`,KD$`"K`Y?__^AVY!`"B["@`\0!\IP@`
M`*<9``"Y!``JLEX`$J<4__ZY"0`:[!P`'P-^N10`(<`P```'..,BK_S_<;)=
M`#*G%/_^IW0`$.P8`M\$?J<:__RY%``1XQ&O__]QE2\0`*>$`M/`Y?___,+L
M)@`0`'ZY!``JISD``,#E___E'+D$`*(8DNPF`+@`?K/-`&C`,```!L'`(```
M!G7`D```!E'`H```!Z#`Y?__]='`Y?__Y'+`4```!P7C(/"H`"3CD/"@`"2Y
M!``HXZ#PL``DITG__Z<Y``'`Y?__Y1VG]``KP.7__^4(U0/0`"``IW0`+;/-
M`&BGN@`!P.7__^1,N10`&^,@\*@`)..@\+@`)+D$`"CCD/"@`"3`4```!MGC
M$/"P`"2G2?__ISD``<#E___D\KD$`"BG.0'`P.7__^4;["C_T/]^L\T`*,#E
M___C$[D$`#C`(```!>?`Y?__]7>Y!``HP.7___RRI_3^JL#E___\K;D$`"O`
MY?__Y0RY!`""I_3^GD&@\.CC$*````*GA``?N00`-^,@H```!,#E___T@>PH
M``<`?)4`(`"G=``&IZL`"*?T_^K`Y?__Y.OL*/_Y`'RY!`"RI_3]>*<I``W`
ML```!CJG:`!3P.7__^/ZN00`HJ?T_8?CH)````2G]/\/ITD``J<Y_^[`Y?__
MXZI!$/'PN00`*K/!`,&Y!``QITD`!L#E___B?94`\?"G=``&E4/Q\:>$`D6Y
M%``9N00`*K/!`.&G20``ISD``$%@\3#`Y?__XX;`$6=%(P'C$/$P`"3`'^_-
MJXGC$/$X`"3`'YBZW/[C$/%``"3`$1`R5';C$/%(`"3`'\/2X?#C$/%0`"1!
M$/%HY4CQ6```L\$`D>5(\6```,`0```%4>5,\:@``.,0\,``)+/-`#RSS0`N
MI4^``,#E___B++D$`*(8DNPL`(L`?N-`\5@`!+D4`!KC,/%@``3K(0`#``VG
M.P`!N0@`),`J`````+DA`$+K/?%@`.+C(/%8`"3K$0`=``RY"``3XQ#Q8``D
MXQ#QJ``2IX0!;Z<H`$"Y^1"2L\T`*1FIL\T`/+GRP)JY&``AN10`N;D$`$O`
MY?__XBL8&5H0\:A0$/&H[!;_L4!^L\T`'+D$`":Y^9":0;L0`,#E___G5.R<
M`!X_?NQY_\``V(AP``;LIR:_`%6GJP`!TC_Q:+``N00`)D&PL$#`Y?__YSVG
MI__VIYK_P(EP``8;E[/-`"FY%`!)N00`.Z=9`$C`Y?__XR^SS0`\L\T`+E"0
M\:BE3X``P.7__^&DN00`HAB2["+_>P!^L\T`+L#E___E">.P\5@`!..@\6``
M!.PK.K]]5;D4`!)!$?%HDH`0`*<J``'L(@$B.'ZSS0`9IS@`.+D8`!*Y^2`C
M["@`(`!^IRK__^LR``@`WNPX`!,`?N-`\,``!.,@%```-M?_$``0`$$0$0"G
M-O_XXT#PP``DN18`(L8@```!7D*@\:-"L/&GZQH`&``,0A#QH.L:`!``#$(0
M\:'K.P`8``Q",/&DZQL`$``,0A#QI;D$`";KJ@`(``Q"H/&BZ[L`"``,0K#Q
MID&@\<=!D/&TI[D`%,#E___FK.,0\3``!$(0\;;K(0`0``Q"(/&TZR$`"``,
M0B#QM>MA`!@`#.,0\3@`!$(0\;KK(0`8``Q"(/&WZR$`$``,0B#QN.L1``@`
M#$(0\;GC$/%```1"$/&^ZR$`&``,0B#QN^LA`!``#$(@\;SK$0`(``Q"$/&]
MXQ#Q2``$0A#QPNLA`!@`#$(@\;_K(0`0``SK$0`(``Q"(/'`0A#QP>,0\5``
M!.LA`!@`#$(0\<9"(/'#0F#QL^LA`!``#.-P\,``!.L1``@`#$(@\<1"$/'%
MN00`*KF$`&:GJP`"P%````1?ITG__Z<Y``'`Y?__XKFGMP`KL\T`:$$0\<?C
M</#``"3C$/"H`"2Y!``HD@#Q[[D$`!?C$/"@`"3`$```!0G`4```!&SC$/"P
M`"2G2?__ISD``<#E___BE*?T_:RSS0"\I_3^N$-@D`"GFP`!I_3_P>,@D`@`
M`J>$_2RG"```IQD``+D$`#*R7@`3IQ3__KD)`!+L'/T>`WWC,2_\_W'`$```
M!#FR70`3IQ3__KGB@**G]/T/L\T`.:<8`$"Y&``RN?D@(>PH`"(`?J<J__^Y
M!``3ZS(`"`#>[#@`$P!^XT#PP``$XR`4```VU_\0`!``01`1`*<V__CC0/#`
M`"2Y%@`BQB````!`N00`)L#E___EL]<W\6CQ:*?T_M>50?'RIW3]NY5#\?.G
M=/VWE4CQ]*=T_;.51?'UIW3]KZ=)``*G.?_&N00`*K/-`&C`Y?__X3>SS0`\
MN00`*J=)`"G`Y?__X`ZY!``H8,#PJ,`0```#':?T_V#`Y?__X)+7`!``$`#7
M`!``$``'!^MO\#``)+)/`!#K$0`@``VR3P`1X_#_4/]QQ(@``#&?T@?PJ!`H
MXR"````60=#PI,#E___C(+D$`++C((```!;`Y?__XQC2`+"Q(+"Y!``]P"``
M``+YP.7___&5["@`!P!\E3$@`*>$`6;`Y?__^$/C((```!;`Y?__XOVG60`+
MITD``<`P```#U\#E___A(^PH`'D`?.,0(!``!.-@$"@`!,`0```Y[^5<$```
M`:?$`&JGF```I[@``:?T`!?C("`0``2G"```LET`)Z<4__ZG=`!0IYH``:>Z
M``'$'0``.=+L&P!*P';C((```!;`Y?__XL&Y!``VIUD``+D4`$G`Y?__XEBY
M!`"B["@`,P!\Q#@``#FTN10`&^L1``,`#>,@(```!.-Q,```!%@0(`RG.`0`
MP!L`(`0`[!/_PH!VXR"````6P.7__^*5XS"@```$IUD``J=)``#`Y?__X"NG
M"```LET`)Z<4__ZGA/^TQ!T``#F(["'__P#8["D`PH!VXR"````6P.7__^)T
MIUD``Z=)``'`,````U'`Y?__X)JY!`"R["@`'P!\XR"````6P.7__^)?XQ"P
M$``$P$````,^XS`0```$P.7__]_CXQ"P$``$XQ`0```$D4`0#:=T`-?C((``
M`!;`Y?__XD.G60`#ITD``<`P```#),#E___@:;D$`++L*``A`'RY!``]P"``
M``']P.7___"TN00`HN,@@```%NRH`)\`?,#E___B(>,0L!``!+D$`$KC,!``
M``3`Y?__WZ;C((```!;`Y?__XA"Y!`"RXR"````6P.7__^((ITD``<`P```"
M[,#E___@H,!````"\;D$`#*Y!``KP.7__]^&XR"````6P.7__^'PD@`@L;D$
M`#W`(````;+`Y?__\&[$*P``..^Y!`"R["@`10!\N00`*Z<Y`<#`Y?__X,?L
M*``)$7[L$@`!`-CL$@!Q`7^R3P`0ZQ$`(``-LD\`$=4'\*@0**=T`&'C0/$@
M``3K;_#@``0'].P<_T$!?J>X``'C((```!:GN@`!P.7__^&NN00`-L#E___>
MN<:]```XKJ=$__"G]/\JE0`@`:>$_IVG]/Z8Q"@``#B=P.7___C:Q"L``#B?
MN00`LNPF_[,`?,`@```"@L#E___@6,#E___AA<08```XAN,@L!``!.,P$```
M!.,@(```!,#E___S?J?T_V#C((```!;`Y?__X6[C$+`0``3C,!````3`Y?__
MX)6G]/\<P.7__]ZPQ!@``#AAN00`4KD$`$O`(````E[C,!````3`Y?__X"`'
M!^NO\%``),#0````U>/P_V#_<;D$`*+`Y?__]=7C$"```)#L&``T`'P80;D$
M`+)!$"`!O4'0`.,P$```D+GB@+$80Z<;``'L-O_V`'S`Y?__]U+L*``5`'[L
MJ``2`'R5`*``IX0`#;D$`"O`,````7[`Y?__W;3LL@`.@&3C0/$0``3KK_#P
M``0']+D$`+*G]/_?N00`*NNO\/``!,#T___QT@<'!P<'!\`0```O>.,0$```
M`J>$``CC4!````3`]/__WKW`4```+X[`]/__WK?K?_`X`"3C\/]@_W&Y!`"2
MN00`@[D$`'3`L```+33`Y?__W47`$```+2JY"0"QZ[L``P`*[+@`$P!\N00`
MH>,0H```!+D$`$>Y!``XN00`*:>K``@-X:>W__3C0/$0``3K?_#8``0']`?^
M!P<'!P<'ZV_P,``DN00`'Z?[_V#C$/```"3`P```+@X'!^-`\1``!.MO\-``
M!`?T!P<```````(``0```````````````"\`7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`````````````1`````"\`````````'_________]P
M97)L>'-I+F,`````````)7,O)7,`+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R
M;V,O)6DO)7,`97AE`"X`4$%27U1%35```%!!4E]04D]'3D%-10``.@`O`%!%
M4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),24\``%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(
M10!005)?05)'0P``4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P``4$%2
M7T=,3T)!3%]435!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X``%!!4E]#3$5!3CT``#$`3$E"4$%42`!,24)205)9
M7U!!5$@``$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@``%-94U1%30``
M)3`R>```)7,E<R5S)7,``'!A<BT``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP``"YP
M87(``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M`"]T;7```%1%35!$25(`5$U0`%5315(``%5315).04U%``!!4D=6```8`'!E
M<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#,V`%5N86)L92!T;R!C
M<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```M
M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@
M;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]
M("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK
M97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R
M.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I
M9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D
M:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR
M96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F
M9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T
M(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@
M/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED
M>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S
M970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K
M97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S
M<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T
M=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB
M=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L
M("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@
M(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R
M.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B
M)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA
M<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L
M;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I
M('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@
M)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C
M*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R
M:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE
M+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL
M87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>
M+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2![
M"B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI
M"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I
M.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S
M("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN
M=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L
M;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@
M4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER
M92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`
M(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<
M,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M
M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E
M;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@
M)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P
M("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*`````1L#.P```-0````9__^!2```!8C__X4@````\/__G;@```$P__^>
MH````8#__Y]@```!L/__HE````'P__^C^````C#__Z2X```"</__I;@```*H
M__^E^````LC__Z98```#"/__IT@```-(__^G4````V#__ZF8```#H/__J=``
M``.X__^K*````_C__ZT````$*/__K:````10__^MX```!'C__Z\P```$N/__
MNC@```4(__^^$```!4C__[ZX```%R/__ON````7@__^_2```!A@`````````
M%``````!>E(``7@.`1L,#Z`!````````/````!S__X0H```8E@!8A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#M`'`QAP"L_.S<S+RLG(Q\8.H`%""P```````$P`
M``!<__^<@````.(`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[``@*@"L_.S<S+
MRLG(Q\8.H`%""V(*QL?(R<K+S,W.SPZ@`4(+````````+````*S__YT8````
MO`!*B@J+"8P(C0>.!H\%1@[0`@*D"L_.S<S+R@Z@`4(+````/````-S__YVH
M```"[`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5,#N`"`P&$"L_.S<S+RLG(Q\8.
MH`%""P```````#P```$<__^@6````:(`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M2@[H`TB8%0)."L_.S<S+RLG(Q\;8#J`!0@L````\```!7/__H<````"\`$:*
M"HL)C`B-!XX&CP5&#L`"`D0*S\[-S,O*#J`!0@L"8,K+S,W.SPZ@`0``````
M````-````9S__Z)````!``!*B`R)"XH*BPF,"(T'C@:/!48.R"("O@K/SLW,
MR\K)R`Z@`4(+```````<```!U/__HP@````\`$R.!H\%1@[``F3/S@Z@`0``
M`#P```'T__^C*````&``1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[(`@)2S\[-
MS,O*R<C'Q@Z@`0`````````````\```"-/__HT@```#P`$J&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.V$("T`K/SLW,R\K)R,?&#J`!0@L`````````%````G3_
M_Z/X````!@``````````````/````HS__Z/H```"1`!*A@Z'#8@,B0N*"HL)
MC`B-!XX&CP5&#N`B`H0*S\[-S,O*R<C'Q@Z@`4(+`````````!0```+,__^E
M\````#0``````````````#P```+D__^F$````5@`1HX&CP5&#L`"`EH*S\X.
MH`%&"V(*S\X.H`%""P*,"L[/#J`!0@MH"L[/#J`!0@L````L```#)/__IR@`
M``'4`%2+"8P(C0>.!H\%1@[P`@,!6@K/SLW,RPZ@`4(+```````D```#5/__
MJ-````"@`$J.!H\%1@[0`@)$"L_.#J`!0@L`````````)````WS__ZE(````
M.@!&C@:/!48.P`)D"L_.#J`!0@L``````````#P```.D__^I8````4X`1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%2@Z@`TB8%0+""L_.S<S+RLG(Q\;8#J`!0@L`
M``!,```#Y/__JG````L&`$:&#H<-B`R)"XH*BPF,"(T'C@:/!5`.N(4"5)@8
MFA>;%IP5`P+""L_.S<S+RLG(Q\;<V]K8#J`!0@L``````````#P```0T__^U
M*````]8`5(8.APV(#(D+B@J+"8P(C0>.!H\%1@[0`@,"Y`K/SLW,R\K)R,?&
M#J`!0@L````````\```$=/__N,````"B`$:*"HL)C`B-!XX&CP5,#L`"`G8*
MS\[-S,O*#J`!0@M2S\[-S,O*#J`!````````````/```!+3__WNX```"A`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5,#N@"`P'0"L_.S<S+RLG(Q\8.H`%""P``
M`````!0```3T__^XZ````"@``````````````#0```4,__^X^````&@`1H<-
MB`R)"XH*BPF,"(T'C@:/!48.P`("6L_.S<S+RLG(QPZ@`0``````%```!43_
M_[DH`````@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````";X````````)J@````````````````````!
M``````````$``````````0````````'?``````````$````````"+@``````
M```,````````&Z``````````#0```````&%H`````````!D```````"[<```
M```````;``````````@`````````&@```````+MX`````````!P`````````
M"`````!O__[U`````````I``````````!0````````SH``````````8`````
M```#<``````````*````````!,0`````````"P`````````8`````````!4`
M```````````````````#````````O9@``````````@````````6(````````
M`!0`````````!P`````````7````````%A@`````````!P```````!+H````
M``````@````````#,``````````)`````````!@`````````'@`````````(
M`````&____L`````"````0````!O___^````````$G@`````;____P``````
M```"`````&____`````````1K`````!O___Y`````````!4`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````+N(````````````````
M`````````````!P.````````'"X````````<3@```````!QN````````'(X`
M```````<K@```````!S.````````'.X````````=#@```````!TN````````
M'4X````````=;@```````!V.````````':X````````=S@```````!WN````
M````'@X````````>+@```````!Y.````````'FX````````>C@```````!ZN
M````````'LX````````>[@```````!\.````````'RX````````?3@``````
M`!]N````````'XX````````?K@```````!_.````````'^X````````@#@``
M`````"`N````````($X````````@;@```````"".````````(*X````````@
MS@```````"#N````````(0X````````A+@```````"%.````````(6X`````
M```AC@```````"&N````````(<X````````A[@```````"(.````````(BX`
M```````B3@```````")N````````(HX````````BK@```````"+.````````
M(NX````````C#@```````",N````````(TX`````````````````````````
M`````````````````````````````````````````````````````````,`(
M`````````````````````````````"-@````````````````````````````
M`````````````````````````````````,`(````````8UH```````!C0@``
M`````&-*````````8W````````!C6````````&-J``````````````````!D
M8````````&)0``````````````````!C!@```````&,*````````9&8`````
M``!B5@```````&1N``````````````````!D<@```````&1X``````````#_
M____`````````````&4:1T-#.B`H56)U;G1U(#8N,RXP+3)U8G5N='4Q*2`V
M+C,N,"`R,#$V,3(R.0!'0T,Z("A58G5N='4@-BXR+C$M-75B=6YT=3(I(#8N
M,BXQ(#(P,38Q,C`R```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M```````+`````0`````````"`````````C@````````".``````````/````
M`````````````````0``````````````$P````<``````````@````````)(
M`````````D@`````````(`````````````````````0``````````````"$`
M```'``````````(````````":`````````)H`````````"0`````````````
M```````$```````````````T;___]@`````````"`````````I`````````"
MD`````````#<````!0``````````````"```````````````/@````L`````
M`````@````````-P`````````W`````````)>`````8````"``````````@`
M````````&````$8````#``````````(````````,Z`````````SH````````
M!,0````````````````````!``````````````!.;____P`````````"````
M````$:P````````1K`````````#*````!0```````````````@`````````"
M````6V____X``````````@```````!)X````````$G@`````````<`````8`
M```"``````````@``````````````&H````$``````````(````````2Z```
M`````!+H`````````S`````%```````````````(`````````!@```!T````
M!`````````!"````````%A@````````6&`````````6(````!0```!8`````
M````"``````````8````?@````$`````````!@```````!N@````````&Z``
M````````0`````````````````````0``````````````'D````!````````
M``8````````;X````````!O@````````!X`````````````````````$````
M`````"````"$`````0`````````&````````(V`````````C8````````#X(
M````````````````````"```````````````B@````$`````````!@``````
M`&%H````````86@`````````+`````````````````````0`````````````
M`)`````!``````````(```````!AF````````&&8````````0'X`````````
M```````````(``````````````"8`````0`````````"````````HA@`````
M``"B&`````````#4````````````````````!```````````````I@````$`
M`````````@```````*+P````````HO`````````%7```````````````````
M``@``````````````+`````.``````````,```````"[<````````*MP````
M``````@````````````````````(``````````@```"\````#P`````````#
M````````NW@```````"K>``````````(````````````````````"```````
M```(````R`````$``````````P```````+N`````````JX``````````"```
M``````````````````@``````````````,T````&``````````,```````"[
MB````````*N(`````````A`````&```````````````(`````````!````#6
M`````0`````````#````````O9@```````"MF`````````)H````````````
M````````"``````````(````VP````$``````````P```````,``````````
ML```````````N`````````````````````@``````````````.$````(````
M``````,```````#`N````````+"X````````$#`````````````````````(
M``````````````#F`````0`````````P``````````````````"PN```````
M``!8`````````````````````0`````````!`````0````,`````````````
M````````````````L1``````````[P````````````````````$`````````
!````
